﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using DataAccessTool; //custom DataAccess class
using System.Data;
using System.Data.SqlClient;

namespace StudentsBusiness
{
    public class StudentMapper
    {
        //this would work because I happened to put the connection string we need as the default:
        //private DataAccess _da = new DataAccess();

        //but we can do this instead and have the DataAccess class
        //not know anything about the DB it's being used for:
        private const string _connectionString = "Data Source=WIN-OA9TV4LURBG\\SQLEXPRESS;Initial Catalog=Exam;Integrated Security=True";
        private DataAccess _da = new DataAccess(_connectionString);

        public StudentMapper()
        {
            _da.GetConnection();
        }

        public string deleteStudent(int studentID)
        {
            SqlParameter[] parameters = new SqlParameter[1];
            parameters[0] = new SqlParameter("studentID", studentID);
            return _da.Execute(System.Data.CommandType.StoredProcedure, "deleteStudent", parameters);
        }

        public List<Student> getAllStudents()
        {
            List<Student> list = new List<Student>();
            DataSet rawData = _da.GetDataSet("getAllStudents", null);

            foreach (DataRow rawRow in rawData.Tables[0].Rows)
            {
                Student student = new Student(rawRow);
                list.Add(student);
            }

            return list;
        }

        public Student getStudentByID(int studentID)
        {
            SqlParameter[] parameters = new SqlParameter[1];
            parameters[0] = new SqlParameter("studentID", studentID);

            DataSet rawData = _da.GetDataSet("getStudentByID", parameters);
            if (rawData.Tables[0].Rows.Count > 0)
            {
                return new Student(rawData.Tables[0].Rows[0]);
            }
            else
            {
                return null;
            }
        }

        public string insertStudent(Student newStudent)
        {
            SqlParameter[] parameters = new SqlParameter[11];
            parameters[0] = new SqlParameter("studentName", newStudent.StudentName);
            parameters[1] = new SqlParameter("studentDescriptionText", SqlDbType.VarChar);
            parameters[1].Value = (object)newStudent.StudentDescriptionText ?? DBNull.Value;
            parameters[2] = new SqlParameter("class1", newStudent.Class1);
            parameters[3] = new SqlParameter("class2", SqlDbType.VarChar);
            parameters[3].Value = (object)newStudent.Class2 ?? DBNull.Value;
            parameters[4] = new SqlParameter("class3", SqlDbType.VarChar);
            parameters[4].Value = (object)newStudent.Class3 ?? DBNull.Value;
            parameters[5] = new SqlParameter("class4", SqlDbType.VarChar);
            parameters[5].Value = (object)newStudent.Class4 ?? DBNull.Value;
            parameters[6] = new SqlParameter("class5", SqlDbType.VarChar);
            parameters[6].Value = (object)newStudent.Class5 ?? DBNull.Value;
            parameters[7] = new SqlParameter("studentImage", SqlDbType.VarChar);
            parameters[7].Value = (object)newStudent.StudentImage ?? DBNull.Value;
            parameters[8] = new SqlParameter("status", newStudent.Status);
            parameters[9] = new SqlParameter("enteredDate", newStudent.EnteredDate);
            parameters[10] = new SqlParameter("ranking", newStudent.Ranking);

            return _da.Execute(System.Data.CommandType.StoredProcedure, "insertStudent", parameters);
        }

        public string updateStudent(Student modStudent)
        {
            SqlParameter[] parameters = new SqlParameter[12];
            parameters[0] = new SqlParameter("studentID", modStudent.StudentID);
            parameters[1] = new SqlParameter("studentName", modStudent.StudentName);
            parameters[2] = new SqlParameter("studentDescriptionText", SqlDbType.VarChar);
            parameters[2].Value = (object)modStudent.StudentDescriptionText ?? DBNull.Value;
            parameters[3] = new SqlParameter("class1", modStudent.Class1);
            parameters[4] = new SqlParameter("class2", SqlDbType.VarChar);
            parameters[4].Value = (object)modStudent.Class2 ?? DBNull.Value;
            parameters[5] = new SqlParameter("class3", SqlDbType.VarChar);
            parameters[5].Value = (object)modStudent.Class3 ?? DBNull.Value;
            parameters[6] = new SqlParameter("class4", SqlDbType.VarChar);
            parameters[6].Value = (object)modStudent.Class4 ?? DBNull.Value;
            parameters[7] = new SqlParameter("class5", SqlDbType.VarChar);
            parameters[7].Value = (object)modStudent.Class5 ?? DBNull.Value;
            parameters[8] = new SqlParameter("studentImage", SqlDbType.VarChar);
            parameters[8].Value = (object)modStudent.StudentImage ?? DBNull.Value;
            parameters[9] = new SqlParameter("status", modStudent.Status);
            parameters[10] = new SqlParameter("enteredDate", modStudent.EnteredDate);
            parameters[11] = new SqlParameter("ranking", modStudent.Ranking);

            return _da.Execute(System.Data.CommandType.StoredProcedure, "updateStudent", parameters);
        }

        public List<Student> getStudentByName(string searchName)
        {
            SqlParameter[] parameters = new SqlParameter[1];
            parameters[0] = new SqlParameter("studentName", searchName);

            List<Student> list = new List<Student>();
            DataSet rawData = _da.GetDataSet("getStudentByName", parameters);

            foreach (DataRow rawRow in rawData.Tables[0].Rows)
            {
                Student student = new Student(rawRow);
                list.Add(student);
            }

            return list;
        }
    }
}
